summaryrefslogtreecommitdiffstats
path: root/src/H5Fpkg.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Fpkg.h')
-rw-r--r--src/H5Fpkg.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/H5Fpkg.h b/src/H5Fpkg.h
index 10f219f..8c43ea2 100644
--- a/src/H5Fpkg.h
+++ b/src/H5Fpkg.h
@@ -54,9 +54,12 @@
#define H5F_SIGNATURE "\211HDF\r\n\032\n"
#define H5F_SIGNATURE_LEN 8
-/*
- * Private file open flags.
- */
+/* Superblock status flags */
+#define H5F_SUPER_WRITE_ACCESS 0x01
+#define H5F_SUPER_FILE_OK 0x02
+#define H5F_SUPER_ALL_FLAGS (H5F_SUPER_WRITE_ACCESS | H5F_SUPER_FILE_OK)
+
+/* Mask for removing private file access flags */
#define H5F_ACC_PUBLIC_FLAGS 0x00ffu
/*
@@ -69,7 +72,7 @@
typedef struct H5F_file_t {
H5FD_t *lf; /* Lower level file handle for I/O */
unsigned nrefs; /* Ref count for times file is opened */
- uint8_t consist_flags; /* File Consistency Flags */
+ uint8_t status_flags; /* File status flags */
unsigned flags; /* Access Permissions for file */
/* Cached values from FCPL/superblock */